==> haskell-src-exts-util-0.2.5-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts-util
version: 0.2.5
id: haskell-src-exts-util-0.2.5-I9AKTh3StJg41deAIx3g1U
key: haskell-src-exts-util-0.2.5-I9AKTh3StJg41deAIx3g1U
license: BSD-3-Clause
copyright: All Rights Reserved
maintainer: pepeiborra@gmail.com
author: Neil Mitchell, Jose Iborra
homepage: https://github.com/pepeiborra/haskell-src-exts-util
synopsis: Helper functions for working with haskell-src-exts trees
description:
    Helper functions for working with haskell-src-exts trees.
category: language
abi: fd98e4adfd6338d3ea461bd85075c221
exposed: True
exposed-modules:
    Language.Haskell.Exts.Util
hidden-modules: Language.Haskell.Exts.Bracket
                Language.Haskell.Exts.FreeVars Language.Haskell.Exts.Util.Internal
                Paths_haskell_src_exts_util
import-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-exts-util-0.2.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/haskell-src-exts-util-0.2.5
hs-libraries: HShaskell-src-exts-util-0.2.5-I9AKTh3StJg41deAIx3g1U
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-default-0.7.1.1-FPe7bpD0gIj5b611SgPKJF
    haskell-src-exts-1.21.0-HshYJhuf4Y04AZKHc18t4c transformers-0.5.6.2
    uniplate-1.6.12-HFtRtCxntHF9QLHAioDTIB
haddock-interfaces: /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock
haddock-html: /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-util-0.2.5-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts-util
version: 0.2.5
id: haskell-src-exts-util-0.2.5-8B77mVuMQsL7vdpBDoZOhW
key: haskell-src-exts-util-0.2.5-8B77mVuMQsL7vdpBDoZOhW
license: BSD-3-Clause
copyright: All Rights Reserved
maintainer: pepeiborra@gmail.com
author: Neil Mitchell, Jose Iborra
homepage: https://github.com/pepeiborra/haskell-src-exts-util
synopsis: Helper functions for working with haskell-src-exts trees
description:
    Helper functions for working with haskell-src-exts trees.
category: language
abi: d43efb421165dfd9d47deb16ccf9680e
exposed: True
exposed-modules:
    Language.Haskell.Exts.Util
hidden-modules: Language.Haskell.Exts.Bracket
                Language.Haskell.Exts.FreeVars Language.Haskell.Exts.Util.Internal
                Paths_haskell_src_exts_util
import-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-exts-util-0.2.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/haskell-src-exts-util-0.2.5
hs-libraries: HShaskell-src-exts-util-0.2.5-8B77mVuMQsL7vdpBDoZOhW
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm
    haskell-src-exts-1.21.0-mhcTUI6FEW8wbumxaToGl transformers-0.5.6.2
    uniplate-1.6.12-7fX2pszesPEJHGunSovUCw
haddock-interfaces: /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock
haddock-html: /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
